@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based AdaptiveURL  package
 
-$Id: interfaces.py 51772 2008-09-23 19:47:45Z cray $
+$Id: interfaces.py 51874 2008-10-20 17:22:49Z cray $
 """
-__author__  = ""
+__author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51772 $"
+__version__ = "$Revision: 51874 $"
  
 from zope.interface import Interface
 
