@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 """The nsinterface class.
 
-$Id: checktocontain.py 51772 2008-09-23 19:47:45Z cray $
+$Id: checktocontain.py 51874 2008-10-20 17:22:49Z cray $
 """
-__author__  = "Dima Khozin & Andrey Orlov"
+__author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51772 $"
-__date__ = "$Date: 2008-09-23 23:47:45 +0400 (Втр, 23 Сен 2008) $"
-__credits__ = """Andrey Orlov, for idea and common control"""
+__version__ = "$Revision: 51874 $"
 
 from zope.interface import implements, implementedBy
 from zope.traversing.interfaces import ITraversable
